@@ -133,6 +133,30 @@ def plan_config(tmp_path, sample_plan_config):
     return c
 
 
+@pytest.fixture
+def sample_plan_unknown_version():
+    return """
+version: -1
+name: Simple plan
+description: A simple plan
+jobs:
+
+- name: tinyconfig
+  builds:
+    - {toolchain: gcc-8, target_arch: i386, kconfig: tinyconfig}
+    - {toolchain: gcc-9, target_arch: i386, kconfig: tinyconfig}
+  test: {device: qemu-i386, tests: [ltp-smoke]}
+"""
+
+
+@pytest.fixture
+def plan_config_unknown_version(tmp_path, sample_plan_unknown_version):
+    config = tmp_path / "plan.yaml"
+    with config.open("w") as f:
+        f.write(sample_plan_unknown_version)
+    return config
+
+
 @pytest.fixture
 def sample_patch():
     return "example mbox patch"
