@@ -543,9 +543,14 @@ class Plan(HeadersMixin):
 
     def load(self, data):
         for (uid, b) in data["builds"].items():
+            git_ref = b.get("git_ref")
+            git_sha = b.get("git_sha")
+            if git_ref:
+                git_sha = None
             build = Build(
                 git_repo=b["git_repo"],
-                git_ref=b["git_ref"],
+                git_ref=git_ref,
+                git_sha=git_sha,
                 target_arch=b["target_arch"],
                 kconfig=b["kconfig"],
                 toolchain=b["toolchain"],
