@@ -734,7 +734,9 @@ DEVICES = [
     "qemu-arm",
     "qemu-armv5",
     "qemu-armv7",
+    "qemu-armv7be",
     "qemu-arm64",
+    "qemu-arm64be",
     "qemu-i386",
     "qemu-mips",
     "qemu-mips32",
